﻿/* RGB_colorwheel
 *
 * A színkör körbejárása RGB színkombinációk alapján.
 * Egy RGB LED folytanatos színátmenetét valósítjuk meg,
 * az analogWrite() függvény használatával.
 *
 * Kapcsolás:
 * - Kössük egy RGB LED közös elektródáját a D4 kimenetre, 
 *   a többi kivezetését pedig egy-egy 510 ohmos áramkorlátozó 
 *   ellenálláson keresztül a D3, D5 és D6 kimenetekre!
 *   
 *   Igazítsuk a programot a LED-hez:
 *   - Közös katódú LED esetén common_level = LOW legyen!
 *   - Közös anódú LED esetén commonlevel = HIGH legyen!
 *         ___________
 *        |           |   3 x  510R
 *        |        D3 |-----/\/\/\--- RED                           L
 *        |        D4 |-------------- Common            E
 *        |        D5 |-----/\/\/\--- GREEN                      D
 *        |        D6 |-----/\/\/\--- BLUE      
 *        |  Arduino  |       
 *        |___________| 
 *     
 */
#define red    3          // Piros LED = D3
#define common 4          // Közös elektróda = D4
#define green  5          // Zöld LED = D5
#define blue   6          // Kék LED = D6
#define common_level HIGH // Közös elektróda (LOW: katód, HIGH: anód)

byte r = 255, g = 0, b = 0;
int t = 25;

void setup() {
  pinMode(common, OUTPUT);
  setRGB();
}

void loop() {
  for (g=0; g < 255; g++,r--) {
    setRGB();                    // Piros -> zöld átmenet
  }
  for (b=0; b < 255; b++,g--) {
    setRGB();                    // Zöld -> kék átmenet
  }
  for (r=0; r < 255; r++,b--) {
    setRGB();                    // Kék -> piros átmenet
  }
}

void setRGB(void) {
  if (common_level == HIGH) {    // Közös anód esete
    digitalWrite(common, HIGH);
    analogWrite(red, 255 - r);
    analogWrite(green, 255 - g);
    analogWrite(blue, 255 - b);
  } else {                       // Közös katód esete
    digitalWrite(common, LOW);
    analogWrite(red, r);
    analogWrite(green, g);
    analogWrite(blue, b);
  }
  delay(t);
}
